==> haskell-auto-update-0.1.6-429-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-HHkMBznrGW1B28kdhiGh82
key:                  auto-update-0.1.6-HHkMBznrGW1B28kdhiGh82
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  cea2236f63c2e012cdc878c6858513fa
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-auto-update
hs-libraries:         HSauto-update-0.1.6-HHkMBznrGW1B28kdhiGh82
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-auto-update-0.1.6-430-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-A7ynHRoH6vfC4VChUsT6sg
key:                  auto-update-0.1.6-A7ynHRoH6vfC4VChUsT6sg
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  ac7256bfbc355c0dbf82e9d34436c093
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-auto-update
hs-libraries:         HSauto-update-0.1.6-A7ynHRoH6vfC4VChUsT6sg
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
